import type { Either } from '@lokalise/node-core';
import type { BarrierResult, CommonCreationConfigType, MessageInvalidFormatError, MessageValidationError, QueuePublisherOptions, ResolvedMessage, SyncPublisher } from '@message-queue-toolkit/core';
import type { ZodSchema } from 'zod';
import type { AMQPDependencies } from './AbstractAmqpService';
import { AbstractAmqpService } from './AbstractAmqpService';
export type AMQPPublisherOptions<MessagePayloadType extends object, CreationConfig extends CommonCreationConfigType, LocatorConfig extends object> = QueuePublisherOptions<CreationConfig, LocatorConfig, MessagePayloadType> & {
    exchange?: string;
};
export declare abstract class AbstractAmqpPublisher<MessagePayloadType extends object, MessageOptionsType, CreationConfig extends CommonCreationConfigType, LocatorConfig extends object> extends AbstractAmqpService<MessagePayloadType, AMQPDependencies, unknown, unknown, CreationConfig, LocatorConfig> implements SyncPublisher<MessagePayloadType, MessageOptionsType> {
    private readonly messageSchemaContainer;
    protected readonly exchange?: string;
    private initPromise?;
    constructor(dependencies: AMQPDependencies, options: AMQPPublisherOptions<MessagePayloadType, CreationConfig, LocatorConfig>);
    publish(message: MessagePayloadType, options: MessageOptionsType): void;
    protected abstract publishInternal(message: Buffer, options: MessageOptionsType): void;
    protected resolveSchema(message: MessagePayloadType): Either<Error, ZodSchema<MessagePayloadType>>;
    protected resolveMessage(): Either<MessageInvalidFormatError | MessageValidationError, ResolvedMessage>;
    protected processPrehandlers(): Promise<unknown>;
    protected preHandlerBarrier<BarrierOutput>(): Promise<BarrierResult<BarrierOutput>>;
    protected resolveNextFunction(): () => void;
    close(): Promise<void>;
    processMessage(): Promise<Either<'retryLater', 'success'>>;
}
