"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AmqpQueuePublisherManager = void 0;
const core_1 = require("@message-queue-toolkit/core");
const CommonAmqpPublisherFactory_1 = require("./CommonAmqpPublisherFactory");
class AmqpQueuePublisherManager extends core_1.AbstractPublisherManager {
    constructor(dependencies, options) {
        super({
            isAsync: false,
            eventRegistry: dependencies.eventRegistry,
            metadataField: options.metadataField ?? 'metadata',
            metadataFiller: options.metadataFiller,
            newPublisherOptions: options.newPublisherOptions,
            publisherDependencies: {
                amqpConnectionManager: dependencies.amqpConnectionManager,
                logger: dependencies.logger,
                errorReporter: dependencies.errorReporter,
            },
            publisherFactory: options.publisherFactory ?? new CommonAmqpPublisherFactory_1.CommonAmqpQueuePublisherFactory(),
        });
    }
    resolveCreationConfig(queueName) {
        return {
            ...this.newPublisherOptions,
            queueOptions: {},
            queueName,
        };
    }
    /**
     * @deprecated use `publishSync` instead.
     */
    publish() {
        throw new Error('Please use `publishSync` method for AMQP publisher managers');
    }
    publishSync(queue, message, precedingEventMetadata, messageOptions) {
        const publisher = this.targetToPublisherMap[queue];
        if (!publisher) {
            throw new Error(`No publisher for queue ${queue}`);
        }
        const messageDefinition = this.resolveMessageDefinition(queue, message);
        const resolvedMessage = this.resolveMessage(messageDefinition, message, precedingEventMetadata);
        publisher.publish(resolvedMessage, messageOptions);
        return resolvedMessage;
    }
    resolveEventTarget(event) {
        return event.queueName;
    }
}
exports.AmqpQueuePublisherManager = AmqpQueuePublisherManager;
//# sourceMappingURL=AmqpQueuePublisherManager.js.map