"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AmqpTopicPublisherManager = void 0;
const core_1 = require("@message-queue-toolkit/core");
const CommonAmqpPublisherFactory_1 = require("./CommonAmqpPublisherFactory");
class AmqpTopicPublisherManager extends core_1.AbstractPublisherManager {
    constructor(dependencies, options) {
        super({
            isAsync: false,
            eventRegistry: dependencies.eventRegistry,
            metadataField: options.metadataField ?? 'metadata',
            metadataFiller: options.metadataFiller,
            newPublisherOptions: options.newPublisherOptions,
            publisherDependencies: {
                amqpConnectionManager: dependencies.amqpConnectionManager,
                logger: dependencies.logger,
                errorReporter: dependencies.errorReporter,
            },
            publisherFactory: options.publisherFactory ?? new CommonAmqpPublisherFactory_1.CommonAmqpTopicPublisherFactory(),
        });
    }
    resolvePublisherConfigOverrides(exchange) {
        return {
            exchange,
        };
    }
    resolveCreationConfig(exchange) {
        return {
            ...this.newPublisherOptions,
            exchange,
            updateAttributesIfExists: false,
        };
    }
    /**
     * @deprecated use `publishSync` instead.
     */
    publish() {
        throw new Error('Please use `publishSync` method for AMQP publisher managers');
    }
    publishSync(exchange, message, messageOptions, precedingEventMetadata) {
        const publisher = this.targetToPublisherMap[exchange];
        if (!publisher) {
            throw new Error(`No publisher for exchange ${exchange}`);
        }
        const messageDefinition = this.resolveMessageDefinition(exchange, message);
        const resolvedMessage = this.resolveMessage(messageDefinition, message, precedingEventMetadata);
        publisher.publish(resolvedMessage, {
            routingKey: messageOptions?.routingKey ?? messageDefinition?.topic ?? '',
            publishOptions: messageOptions?.publishOptions,
        });
        return resolvedMessage;
    }
    resolveEventTarget(event) {
        return event.exchange;
    }
}
exports.AmqpTopicPublisherManager = AmqpTopicPublisherManager;
//# sourceMappingURL=AmqpTopicPublisherManager.js.map